import reflex as rx

class HiAcademicCap(rx.Component):
    library = "react-icons/hi"
    tag = "HiAcademicCap"


class HiAdjustments(rx.Component):
    library = "react-icons/hi"
    tag = "HiAdjustments"


class HiAnnotation(rx.Component):
    library = "react-icons/hi"
    tag = "HiAnnotation"


class HiArchive(rx.Component):
    library = "react-icons/hi"
    tag = "HiArchive"


class HiArrowCircleDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowCircleDown"


class HiArrowCircleLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowCircleLeft"


class HiArrowCircleRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowCircleRight"


class HiArrowCircleUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowCircleUp"


class HiArrowDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowDown"


class HiArrowLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowLeft"


class HiArrowNarrowDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowNarrowDown"


class HiArrowNarrowLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowNarrowLeft"


class HiArrowNarrowRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowNarrowRight"


class HiArrowNarrowUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowNarrowUp"


class HiArrowRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowRight"


class HiArrowSmDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowSmDown"


class HiArrowSmLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowSmLeft"


class HiArrowSmRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowSmRight"


class HiArrowSmUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowSmUp"


class HiArrowUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowUp"


class HiArrowsExpand(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowsExpand"


class HiAtSymbol(rx.Component):
    library = "react-icons/hi"
    tag = "HiAtSymbol"


class HiBackspace(rx.Component):
    library = "react-icons/hi"
    tag = "HiBackspace"


class HiBadgeCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiBadgeCheck"


class HiBan(rx.Component):
    library = "react-icons/hi"
    tag = "HiBan"


class HiBeaker(rx.Component):
    library = "react-icons/hi"
    tag = "HiBeaker"


class HiBell(rx.Component):
    library = "react-icons/hi"
    tag = "HiBell"


class HiBookOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiBookOpen"


class HiBookmarkAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiBookmarkAlt"


class HiBookmark(rx.Component):
    library = "react-icons/hi"
    tag = "HiBookmark"


class HiBriefcase(rx.Component):
    library = "react-icons/hi"
    tag = "HiBriefcase"


class HiCake(rx.Component):
    library = "react-icons/hi"
    tag = "HiCake"


class HiCalculator(rx.Component):
    library = "react-icons/hi"
    tag = "HiCalculator"


class HiCalendar(rx.Component):
    library = "react-icons/hi"
    tag = "HiCalendar"


class HiCamera(rx.Component):
    library = "react-icons/hi"
    tag = "HiCamera"


class HiCash(rx.Component):
    library = "react-icons/hi"
    tag = "HiCash"


class HiChartBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiChartBar"


class HiChartPie(rx.Component):
    library = "react-icons/hi"
    tag = "HiChartPie"


class HiChartSquareBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiChartSquareBar"


class HiChatAlt2(rx.Component):
    library = "react-icons/hi"
    tag = "HiChatAlt2"


class HiChatAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiChatAlt"


class HiChat(rx.Component):
    library = "react-icons/hi"
    tag = "HiChat"


class HiCheckCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiCheckCircle"


class HiCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiCheck"


class HiChevronDoubleDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDoubleDown"


class HiChevronDoubleLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDoubleLeft"


class HiChevronDoubleRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDoubleRight"


class HiChevronDoubleUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDoubleUp"


class HiChevronDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDown"


class HiChevronLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronLeft"


class HiChevronRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronRight"


class HiChevronUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronUp"


class HiChip(rx.Component):
    library = "react-icons/hi"
    tag = "HiChip"


class HiClipboardCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiClipboardCheck"


class HiClipboardCopy(rx.Component):
    library = "react-icons/hi"
    tag = "HiClipboardCopy"


class HiClipboardList(rx.Component):
    library = "react-icons/hi"
    tag = "HiClipboardList"


class HiClipboard(rx.Component):
    library = "react-icons/hi"
    tag = "HiClipboard"


class HiClock(rx.Component):
    library = "react-icons/hi"
    tag = "HiClock"


class HiCloudDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiCloudDownload"


class HiCloudUpload(rx.Component):
    library = "react-icons/hi"
    tag = "HiCloudUpload"


class HiCloud(rx.Component):
    library = "react-icons/hi"
    tag = "HiCloud"


class HiCode(rx.Component):
    library = "react-icons/hi"
    tag = "HiCode"


class HiCog(rx.Component):
    library = "react-icons/hi"
    tag = "HiCog"


class HiCollection(rx.Component):
    library = "react-icons/hi"
    tag = "HiCollection"


class HiColorSwatch(rx.Component):
    library = "react-icons/hi"
    tag = "HiColorSwatch"


class HiCreditCard(rx.Component):
    library = "react-icons/hi"
    tag = "HiCreditCard"


class HiCubeTransparent(rx.Component):
    library = "react-icons/hi"
    tag = "HiCubeTransparent"


class HiCube(rx.Component):
    library = "react-icons/hi"
    tag = "HiCube"


class HiCurrencyBangladeshi(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyBangladeshi"


class HiCurrencyDollar(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyDollar"


class HiCurrencyEuro(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyEuro"


class HiCurrencyPound(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyPound"


class HiCurrencyRupee(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyRupee"


class HiCurrencyYen(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyYen"


class HiCursorClick(rx.Component):
    library = "react-icons/hi"
    tag = "HiCursorClick"


class HiDatabase(rx.Component):
    library = "react-icons/hi"
    tag = "HiDatabase"


class HiDesktopComputer(rx.Component):
    library = "react-icons/hi"
    tag = "HiDesktopComputer"


class HiDeviceMobile(rx.Component):
    library = "react-icons/hi"
    tag = "HiDeviceMobile"


class HiDeviceTablet(rx.Component):
    library = "react-icons/hi"
    tag = "HiDeviceTablet"


class HiDocumentAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentAdd"


class HiDocumentDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentDownload"


class HiDocumentDuplicate(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentDuplicate"


class HiDocumentRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentRemove"


class HiDocumentReport(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentReport"


class HiDocumentSearch(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentSearch"


class HiDocumentText(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentText"


class HiDocument(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocument"


class HiDotsCircleHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiDotsCircleHorizontal"


class HiDotsHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiDotsHorizontal"


class HiDotsVertical(rx.Component):
    library = "react-icons/hi"
    tag = "HiDotsVertical"


class HiDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiDownload"


class HiDuplicate(rx.Component):
    library = "react-icons/hi"
    tag = "HiDuplicate"


class HiEmojiHappy(rx.Component):
    library = "react-icons/hi"
    tag = "HiEmojiHappy"


class HiEmojiSad(rx.Component):
    library = "react-icons/hi"
    tag = "HiEmojiSad"


class HiExclamationCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiExclamationCircle"


class HiExclamation(rx.Component):
    library = "react-icons/hi"
    tag = "HiExclamation"


class HiExternalLink(rx.Component):
    library = "react-icons/hi"
    tag = "HiExternalLink"


class HiEyeOff(rx.Component):
    library = "react-icons/hi"
    tag = "HiEyeOff"


class HiEye(rx.Component):
    library = "react-icons/hi"
    tag = "HiEye"


class HiFastForward(rx.Component):
    library = "react-icons/hi"
    tag = "HiFastForward"


class HiFilm(rx.Component):
    library = "react-icons/hi"
    tag = "HiFilm"


class HiFilter(rx.Component):
    library = "react-icons/hi"
    tag = "HiFilter"


class HiFingerPrint(rx.Component):
    library = "react-icons/hi"
    tag = "HiFingerPrint"


class HiFire(rx.Component):
    library = "react-icons/hi"
    tag = "HiFire"


class HiFlag(rx.Component):
    library = "react-icons/hi"
    tag = "HiFlag"


class HiFolderAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolderAdd"


class HiFolderDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolderDownload"


class HiFolderOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolderOpen"


class HiFolderRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolderRemove"


class HiFolder(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolder"


class HiGift(rx.Component):
    library = "react-icons/hi"
    tag = "HiGift"


class HiGlobeAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiGlobeAlt"


class HiGlobe(rx.Component):
    library = "react-icons/hi"
    tag = "HiGlobe"


class HiHand(rx.Component):
    library = "react-icons/hi"
    tag = "HiHand"


class HiHashtag(rx.Component):
    library = "react-icons/hi"
    tag = "HiHashtag"


class HiHeart(rx.Component):
    library = "react-icons/hi"
    tag = "HiHeart"


class HiHome(rx.Component):
    library = "react-icons/hi"
    tag = "HiHome"


class HiIdentification(rx.Component):
    library = "react-icons/hi"
    tag = "HiIdentification"


class HiInboxIn(rx.Component):
    library = "react-icons/hi"
    tag = "HiInboxIn"


class HiInbox(rx.Component):
    library = "react-icons/hi"
    tag = "HiInbox"


class HiInformationCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiInformationCircle"


class HiKey(rx.Component):
    library = "react-icons/hi"
    tag = "HiKey"


class HiLibrary(rx.Component):
    library = "react-icons/hi"
    tag = "HiLibrary"


class HiLightBulb(rx.Component):
    library = "react-icons/hi"
    tag = "HiLightBulb"


class HiLightningBolt(rx.Component):
    library = "react-icons/hi"
    tag = "HiLightningBolt"


class HiLink(rx.Component):
    library = "react-icons/hi"
    tag = "HiLink"


class HiLocationMarker(rx.Component):
    library = "react-icons/hi"
    tag = "HiLocationMarker"


class HiLockClosed(rx.Component):
    library = "react-icons/hi"
    tag = "HiLockClosed"


class HiLockOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiLockOpen"


class HiLogin(rx.Component):
    library = "react-icons/hi"
    tag = "HiLogin"


class HiLogout(rx.Component):
    library = "react-icons/hi"
    tag = "HiLogout"


class HiMailOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiMailOpen"


class HiMail(rx.Component):
    library = "react-icons/hi"
    tag = "HiMail"


class HiMap(rx.Component):
    library = "react-icons/hi"
    tag = "HiMap"


class HiMenuAlt1(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenuAlt1"


class HiMenuAlt2(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenuAlt2"


class HiMenuAlt3(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenuAlt3"


class HiMenuAlt4(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenuAlt4"


class HiMenu(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenu"


class HiMicrophone(rx.Component):
    library = "react-icons/hi"
    tag = "HiMicrophone"


class HiMinusCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiMinusCircle"


class HiMinusSm(rx.Component):
    library = "react-icons/hi"
    tag = "HiMinusSm"


class HiMinus(rx.Component):
    library = "react-icons/hi"
    tag = "HiMinus"


class HiMoon(rx.Component):
    library = "react-icons/hi"
    tag = "HiMoon"


class HiMusicNote(rx.Component):
    library = "react-icons/hi"
    tag = "HiMusicNote"


class HiNewspaper(rx.Component):
    library = "react-icons/hi"
    tag = "HiNewspaper"


class HiOfficeBuilding(rx.Component):
    library = "react-icons/hi"
    tag = "HiOfficeBuilding"


class HiPaperAirplane(rx.Component):
    library = "react-icons/hi"
    tag = "HiPaperAirplane"


class HiPaperClip(rx.Component):
    library = "react-icons/hi"
    tag = "HiPaperClip"


class HiPause(rx.Component):
    library = "react-icons/hi"
    tag = "HiPause"


class HiPencilAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiPencilAlt"


class HiPencil(rx.Component):
    library = "react-icons/hi"
    tag = "HiPencil"


class HiPhoneIncoming(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhoneIncoming"


class HiPhoneMissedCall(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhoneMissedCall"


class HiPhoneOutgoing(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhoneOutgoing"


class HiPhone(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhone"


class HiPhotograph(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhotograph"


class HiPlay(rx.Component):
    library = "react-icons/hi"
    tag = "HiPlay"


class HiPlusCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiPlusCircle"


class HiPlusSm(rx.Component):
    library = "react-icons/hi"
    tag = "HiPlusSm"


class HiPlus(rx.Component):
    library = "react-icons/hi"
    tag = "HiPlus"


class HiPresentationChartBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiPresentationChartBar"


class HiPresentationChartLine(rx.Component):
    library = "react-icons/hi"
    tag = "HiPresentationChartLine"


class HiPrinter(rx.Component):
    library = "react-icons/hi"
    tag = "HiPrinter"


class HiPuzzle(rx.Component):
    library = "react-icons/hi"
    tag = "HiPuzzle"


class HiQrcode(rx.Component):
    library = "react-icons/hi"
    tag = "HiQrcode"


class HiQuestionMarkCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiQuestionMarkCircle"


class HiReceiptRefund(rx.Component):
    library = "react-icons/hi"
    tag = "HiReceiptRefund"


class HiReceiptTax(rx.Component):
    library = "react-icons/hi"
    tag = "HiReceiptTax"


class HiRefresh(rx.Component):
    library = "react-icons/hi"
    tag = "HiRefresh"


class HiReply(rx.Component):
    library = "react-icons/hi"
    tag = "HiReply"


class HiRewind(rx.Component):
    library = "react-icons/hi"
    tag = "HiRewind"


class HiRss(rx.Component):
    library = "react-icons/hi"
    tag = "HiRss"


class HiSaveAs(rx.Component):
    library = "react-icons/hi"
    tag = "HiSaveAs"


class HiSave(rx.Component):
    library = "react-icons/hi"
    tag = "HiSave"


class HiScale(rx.Component):
    library = "react-icons/hi"
    tag = "HiScale"


class HiScissors(rx.Component):
    library = "react-icons/hi"
    tag = "HiScissors"


class HiSearchCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiSearchCircle"


class HiSearch(rx.Component):
    library = "react-icons/hi"
    tag = "HiSearch"


class HiSelector(rx.Component):
    library = "react-icons/hi"
    tag = "HiSelector"


class HiServer(rx.Component):
    library = "react-icons/hi"
    tag = "HiServer"


class HiShare(rx.Component):
    library = "react-icons/hi"
    tag = "HiShare"


class HiShieldCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiShieldCheck"


class HiShieldExclamation(rx.Component):
    library = "react-icons/hi"
    tag = "HiShieldExclamation"


class HiShoppingBag(rx.Component):
    library = "react-icons/hi"
    tag = "HiShoppingBag"


class HiShoppingCart(rx.Component):
    library = "react-icons/hi"
    tag = "HiShoppingCart"


class HiSortAscending(rx.Component):
    library = "react-icons/hi"
    tag = "HiSortAscending"


class HiSortDescending(rx.Component):
    library = "react-icons/hi"
    tag = "HiSortDescending"


class HiSparkles(rx.Component):
    library = "react-icons/hi"
    tag = "HiSparkles"


class HiSpeakerphone(rx.Component):
    library = "react-icons/hi"
    tag = "HiSpeakerphone"


class HiStar(rx.Component):
    library = "react-icons/hi"
    tag = "HiStar"


class HiStatusOffline(rx.Component):
    library = "react-icons/hi"
    tag = "HiStatusOffline"


class HiStatusOnline(rx.Component):
    library = "react-icons/hi"
    tag = "HiStatusOnline"


class HiStop(rx.Component):
    library = "react-icons/hi"
    tag = "HiStop"


class HiSun(rx.Component):
    library = "react-icons/hi"
    tag = "HiSun"


class HiSupport(rx.Component):
    library = "react-icons/hi"
    tag = "HiSupport"


class HiSwitchHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiSwitchHorizontal"


class HiSwitchVertical(rx.Component):
    library = "react-icons/hi"
    tag = "HiSwitchVertical"


class HiTable(rx.Component):
    library = "react-icons/hi"
    tag = "HiTable"


class HiTag(rx.Component):
    library = "react-icons/hi"
    tag = "HiTag"


class HiTemplate(rx.Component):
    library = "react-icons/hi"
    tag = "HiTemplate"


class HiTerminal(rx.Component):
    library = "react-icons/hi"
    tag = "HiTerminal"


class HiThumbDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiThumbDown"


class HiThumbUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiThumbUp"


class HiTicket(rx.Component):
    library = "react-icons/hi"
    tag = "HiTicket"


class HiTranslate(rx.Component):
    library = "react-icons/hi"
    tag = "HiTranslate"


class HiTrash(rx.Component):
    library = "react-icons/hi"
    tag = "HiTrash"


class HiTrendingDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiTrendingDown"


class HiTrendingUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiTrendingUp"


class HiTruck(rx.Component):
    library = "react-icons/hi"
    tag = "HiTruck"


class HiUpload(rx.Component):
    library = "react-icons/hi"
    tag = "HiUpload"


class HiUserAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiUserAdd"


class HiUserCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiUserCircle"


class HiUserGroup(rx.Component):
    library = "react-icons/hi"
    tag = "HiUserGroup"


class HiUserRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiUserRemove"


class HiUser(rx.Component):
    library = "react-icons/hi"
    tag = "HiUser"


class HiUsers(rx.Component):
    library = "react-icons/hi"
    tag = "HiUsers"


class HiVariable(rx.Component):
    library = "react-icons/hi"
    tag = "HiVariable"


class HiVideoCamera(rx.Component):
    library = "react-icons/hi"
    tag = "HiVideoCamera"


class HiViewBoards(rx.Component):
    library = "react-icons/hi"
    tag = "HiViewBoards"


class HiViewGridAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiViewGridAdd"


class HiViewGrid(rx.Component):
    library = "react-icons/hi"
    tag = "HiViewGrid"


class HiViewList(rx.Component):
    library = "react-icons/hi"
    tag = "HiViewList"


class HiVolumeOff(rx.Component):
    library = "react-icons/hi"
    tag = "HiVolumeOff"


class HiVolumeUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiVolumeUp"


class HiWifi(rx.Component):
    library = "react-icons/hi"
    tag = "HiWifi"


class HiXCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiXCircle"


class HiX(rx.Component):
    library = "react-icons/hi"
    tag = "HiX"


class HiZoomIn(rx.Component):
    library = "react-icons/hi"
    tag = "HiZoomIn"


class HiZoomOut(rx.Component):
    library = "react-icons/hi"
    tag = "HiZoomOut"


class HiOutlineAcademicCap(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineAcademicCap"


class HiOutlineAdjustments(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineAdjustments"


class HiOutlineAnnotation(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineAnnotation"


class HiOutlineArchive(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArchive"


class HiOutlineArrowCircleDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowCircleDown"


class HiOutlineArrowCircleLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowCircleLeft"


class HiOutlineArrowCircleRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowCircleRight"


class HiOutlineArrowCircleUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowCircleUp"


class HiOutlineArrowDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowDown"


class HiOutlineArrowLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowLeft"


class HiOutlineArrowNarrowDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowNarrowDown"


class HiOutlineArrowNarrowLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowNarrowLeft"


class HiOutlineArrowNarrowRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowNarrowRight"


class HiOutlineArrowNarrowUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowNarrowUp"


class HiOutlineArrowRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowRight"


class HiOutlineArrowSmDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowSmDown"


class HiOutlineArrowSmLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowSmLeft"


class HiOutlineArrowSmRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowSmRight"


class HiOutlineArrowSmUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowSmUp"


class HiOutlineArrowUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowUp"


class HiOutlineArrowsExpand(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowsExpand"


class HiOutlineAtSymbol(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineAtSymbol"


class HiOutlineBackspace(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBackspace"


class HiOutlineBadgeCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBadgeCheck"


class HiOutlineBan(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBan"


class HiOutlineBeaker(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBeaker"


class HiOutlineBell(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBell"


class HiOutlineBookOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBookOpen"


class HiOutlineBookmarkAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBookmarkAlt"


class HiOutlineBookmark(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBookmark"


class HiOutlineBriefcase(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBriefcase"


class HiOutlineCake(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCake"


class HiOutlineCalculator(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCalculator"


class HiOutlineCalendar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCalendar"


class HiOutlineCamera(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCamera"


class HiOutlineCash(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCash"


class HiOutlineChartBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChartBar"


class HiOutlineChartPie(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChartPie"


class HiOutlineChartSquareBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChartSquareBar"


class HiOutlineChatAlt2(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChatAlt2"


class HiOutlineChatAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChatAlt"


class HiOutlineChat(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChat"


class HiOutlineCheckCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCheckCircle"


class HiOutlineCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCheck"


class HiOutlineChevronDoubleDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDoubleDown"


class HiOutlineChevronDoubleLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDoubleLeft"


class HiOutlineChevronDoubleRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDoubleRight"


class HiOutlineChevronDoubleUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDoubleUp"


class HiOutlineChevronDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDown"


class HiOutlineChevronLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronLeft"


class HiOutlineChevronRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronRight"


class HiOutlineChevronUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronUp"


class HiOutlineChip(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChip"


class HiOutlineClipboardCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClipboardCheck"


class HiOutlineClipboardCopy(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClipboardCopy"


class HiOutlineClipboardList(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClipboardList"


class HiOutlineClipboard(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClipboard"


class HiOutlineClock(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClock"


class HiOutlineCloudDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCloudDownload"


class HiOutlineCloudUpload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCloudUpload"


class HiOutlineCloud(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCloud"


class HiOutlineCode(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCode"


class HiOutlineCog(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCog"


class HiOutlineCollection(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCollection"


class HiOutlineColorSwatch(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineColorSwatch"


class HiOutlineCreditCard(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCreditCard"


class HiOutlineCubeTransparent(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCubeTransparent"


class HiOutlineCube(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCube"


class HiOutlineCurrencyBangladeshi(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyBangladeshi"


class HiOutlineCurrencyDollar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyDollar"


class HiOutlineCurrencyEuro(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyEuro"


class HiOutlineCurrencyPound(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyPound"


class HiOutlineCurrencyRupee(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyRupee"


class HiOutlineCurrencyYen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyYen"


class HiOutlineCursorClick(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCursorClick"


class HiOutlineDatabase(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDatabase"


class HiOutlineDesktopComputer(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDesktopComputer"


class HiOutlineDeviceMobile(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDeviceMobile"


class HiOutlineDeviceTablet(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDeviceTablet"


class HiOutlineDocumentAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentAdd"


class HiOutlineDocumentDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentDownload"


class HiOutlineDocumentDuplicate(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentDuplicate"


class HiOutlineDocumentRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentRemove"


class HiOutlineDocumentReport(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentReport"


class HiOutlineDocumentSearch(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentSearch"


class HiOutlineDocumentText(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentText"


class HiOutlineDocument(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocument"


class HiOutlineDotsCircleHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDotsCircleHorizontal"


class HiOutlineDotsHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDotsHorizontal"


class HiOutlineDotsVertical(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDotsVertical"


class HiOutlineDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDownload"


class HiOutlineDuplicate(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDuplicate"


class HiOutlineEmojiHappy(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineEmojiHappy"


class HiOutlineEmojiSad(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineEmojiSad"


class HiOutlineExclamationCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineExclamationCircle"


class HiOutlineExclamation(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineExclamation"


class HiOutlineExternalLink(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineExternalLink"


class HiOutlineEyeOff(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineEyeOff"


class HiOutlineEye(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineEye"


class HiOutlineFastForward(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFastForward"


class HiOutlineFilm(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFilm"


class HiOutlineFilter(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFilter"


class HiOutlineFingerPrint(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFingerPrint"


class HiOutlineFire(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFire"


class HiOutlineFlag(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFlag"


class HiOutlineFolderAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolderAdd"


class HiOutlineFolderDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolderDownload"


class HiOutlineFolderOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolderOpen"


class HiOutlineFolderRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolderRemove"


class HiOutlineFolder(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolder"


class HiOutlineGift(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineGift"


class HiOutlineGlobeAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineGlobeAlt"


class HiOutlineGlobe(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineGlobe"


class HiOutlineHand(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineHand"


class HiOutlineHashtag(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineHashtag"


class HiOutlineHeart(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineHeart"


class HiOutlineHome(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineHome"


class HiOutlineIdentification(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineIdentification"


class HiOutlineInboxIn(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineInboxIn"


class HiOutlineInbox(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineInbox"


class HiOutlineInformationCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineInformationCircle"


class HiOutlineKey(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineKey"


class HiOutlineLibrary(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLibrary"


class HiOutlineLightBulb(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLightBulb"


class HiOutlineLightningBolt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLightningBolt"


class HiOutlineLink(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLink"


class HiOutlineLocationMarker(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLocationMarker"


class HiOutlineLockClosed(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLockClosed"


class HiOutlineLockOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLockOpen"


class HiOutlineLogin(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLogin"


class HiOutlineLogout(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLogout"


class HiOutlineMailOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMailOpen"


class HiOutlineMail(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMail"


class HiOutlineMap(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMap"


class HiOutlineMenuAlt1(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenuAlt1"


class HiOutlineMenuAlt2(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenuAlt2"


class HiOutlineMenuAlt3(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenuAlt3"


class HiOutlineMenuAlt4(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenuAlt4"


class HiOutlineMenu(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenu"


class HiOutlineMicrophone(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMicrophone"


class HiOutlineMinusCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMinusCircle"


class HiOutlineMinusSm(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMinusSm"


class HiOutlineMinus(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMinus"


class HiOutlineMoon(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMoon"


class HiOutlineMusicNote(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMusicNote"


class HiOutlineNewspaper(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineNewspaper"


class HiOutlineOfficeBuilding(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineOfficeBuilding"


class HiOutlinePaperAirplane(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePaperAirplane"


class HiOutlinePaperClip(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePaperClip"


class HiOutlinePause(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePause"


class HiOutlinePencilAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePencilAlt"


class HiOutlinePencil(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePencil"


class HiOutlinePhoneIncoming(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhoneIncoming"


class HiOutlinePhoneMissedCall(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhoneMissedCall"


class HiOutlinePhoneOutgoing(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhoneOutgoing"


class HiOutlinePhone(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhone"


class HiOutlinePhotograph(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhotograph"


class HiOutlinePlay(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePlay"


class HiOutlinePlusCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePlusCircle"


class HiOutlinePlusSm(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePlusSm"


class HiOutlinePlus(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePlus"


class HiOutlinePresentationChartBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePresentationChartBar"


class HiOutlinePresentationChartLine(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePresentationChartLine"


class HiOutlinePrinter(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePrinter"


class HiOutlinePuzzle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePuzzle"


class HiOutlineQrcode(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineQrcode"


class HiOutlineQuestionMarkCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineQuestionMarkCircle"


class HiOutlineReceiptRefund(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineReceiptRefund"


class HiOutlineReceiptTax(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineReceiptTax"


class HiOutlineRefresh(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineRefresh"


class HiOutlineReply(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineReply"


class HiOutlineRewind(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineRewind"


class HiOutlineRss(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineRss"


class HiOutlineSaveAs(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSaveAs"


class HiOutlineSave(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSave"


class HiOutlineScale(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineScale"


class HiOutlineScissors(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineScissors"


class HiOutlineSearchCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSearchCircle"


class HiOutlineSearch(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSearch"


class HiOutlineSelector(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSelector"


class HiOutlineServer(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineServer"


class HiOutlineShare(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShare"


class HiOutlineShieldCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShieldCheck"


class HiOutlineShieldExclamation(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShieldExclamation"


class HiOutlineShoppingBag(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShoppingBag"


class HiOutlineShoppingCart(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShoppingCart"


class HiOutlineSortAscending(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSortAscending"


class HiOutlineSortDescending(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSortDescending"


class HiOutlineSparkles(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSparkles"


class HiOutlineSpeakerphone(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSpeakerphone"


class HiOutlineStar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineStar"


class HiOutlineStatusOffline(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineStatusOffline"


class HiOutlineStatusOnline(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineStatusOnline"


class HiOutlineStop(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineStop"


class HiOutlineSun(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSun"


class HiOutlineSupport(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSupport"


class HiOutlineSwitchHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSwitchHorizontal"


class HiOutlineSwitchVertical(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSwitchVertical"


class HiOutlineTable(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTable"


class HiOutlineTag(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTag"


class HiOutlineTemplate(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTemplate"


class HiOutlineTerminal(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTerminal"


class HiOutlineThumbDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineThumbDown"


class HiOutlineThumbUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineThumbUp"


class HiOutlineTicket(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTicket"


class HiOutlineTranslate(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTranslate"


class HiOutlineTrash(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTrash"


class HiOutlineTrendingDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTrendingDown"


class HiOutlineTrendingUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTrendingUp"


class HiOutlineTruck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTruck"


class HiOutlineUpload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUpload"


class HiOutlineUserAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUserAdd"


class HiOutlineUserCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUserCircle"


class HiOutlineUserGroup(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUserGroup"


class HiOutlineUserRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUserRemove"


class HiOutlineUser(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUser"


class HiOutlineUsers(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUsers"


class HiOutlineVariable(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineVariable"


class HiOutlineVideoCamera(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineVideoCamera"


class HiOutlineViewBoards(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineViewBoards"


class HiOutlineViewGridAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineViewGridAdd"


class HiOutlineViewGrid(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineViewGrid"


class HiOutlineViewList(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineViewList"


class HiOutlineVolumeOff(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineVolumeOff"


class HiOutlineVolumeUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineVolumeUp"


class HiOutlineWifi(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineWifi"


class HiOutlineXCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineXCircle"


class HiOutlineX(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineX"


class HiOutlineZoomIn(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineZoomIn"


class HiOutlineZoomOut(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineZoomOut"





import reflex as rx

class ImHome(rx.Component):
    library = "react-icons/im"
    tag = "ImHome"


class ImHome2(rx.Component):
    library = "react-icons/im"
    tag = "ImHome2"


class ImHome3(rx.Component):
    library = "react-icons/im"
    tag = "ImHome3"


class ImOffice(rx.Component):
    library = "react-icons/im"
    tag = "ImOffice"


class ImNewspaper(rx.Component):
    library = "react-icons/im"
    tag = "ImNewspaper"


class ImPencil(rx.Component):
    library = "react-icons/im"
    tag = "ImPencil"


class ImPencil2(rx.Component):
    library = "react-icons/im"
    tag = "ImPencil2"


class ImQuill(rx.Component):
    library = "react-icons/im"
    tag = "ImQuill"


class ImPen(rx.Component):
    library = "react-icons/im"
    tag = "ImPen"


class ImBlog(rx.Component):
    library = "react-icons/im"
    tag = "ImBlog"


class ImEyedropper(rx.Component):
    library = "react-icons/im"
    tag = "ImEyedropper"


class ImDroplet(rx.Component):
    library = "react-icons/im"
    tag = "ImDroplet"


class ImPaintFormat(rx.Component):
    library = "react-icons/im"
    tag = "ImPaintFormat"


class ImImage(rx.Component):
    library = "react-icons/im"
    tag = "ImImage"


class ImImages(rx.Component):
    library = "react-icons/im"
    tag = "ImImages"


class ImCamera(rx.Component):
    library = "react-icons/im"
    tag = "ImCamera"


class ImHeadphones(rx.Component):
    library = "react-icons/im"
    tag = "ImHeadphones"


class ImMusic(rx.Component):
    library = "react-icons/im"
    tag = "ImMusic"


class ImPlay(rx.Component):
    library = "react-icons/im"
    tag = "ImPlay"


class ImFilm(rx.Component):
    library = "react-icons/im"
    tag = "ImFilm"


class ImVideoCamera(rx.Component):
    library = "react-icons/im"
    tag = "ImVideoCamera"


class ImDice(rx.Component):
    library = "react-icons/im"
    tag = "ImDice"


class ImPacman(rx.Component):
    library = "react-icons/im"
    tag = "ImPacman"


class ImSpades(rx.Component):
    library = "react-icons/im"
    tag = "ImSpades"


class ImClubs(rx.Component):
    library = "react-icons/im"
    tag = "ImClubs"


class ImDiamonds(rx.Component):
    library = "react-icons/im"
    tag = "ImDiamonds"


class ImBullhorn(rx.Component):
    library = "react-icons/im"
    tag = "ImBullhorn"


class ImConnection(rx.Component):
    library = "react-icons/im"
    tag = "ImConnection"


class ImPodcast(rx.Component):
    library = "react-icons/im"
    tag = "ImPodcast"


class ImFeed(rx.Component):
    library = "react-icons/im"
    tag = "ImFeed"


class ImMic(rx.Component):
    library = "react-icons/im"
    tag = "ImMic"


class ImBook(rx.Component):
    library = "react-icons/im"
    tag = "ImBook"


class ImBooks(rx.Component):
    library = "react-icons/im"
    tag = "ImBooks"


class ImLibrary(rx.Component):
    library = "react-icons/im"
    tag = "ImLibrary"


class ImFileText(rx.Component):
    library = "react-icons/im"
    tag = "ImFileText"


class ImProfile(rx.Component):
    library = "react-icons/im"
    tag = "ImProfile"


class ImFileEmpty(rx.Component):
    library = "react-icons/im"
    tag = "ImFileEmpty"


class ImFilesEmpty(rx.Component):
    library = "react-icons/im"
    tag = "ImFilesEmpty"


class ImFileText2(rx.Component):
    library = "react-icons/im"
    tag = "ImFileText2"


class ImFilePicture(rx.Component):
    library = "react-icons/im"
    tag = "ImFilePicture"


class ImFileMusic(rx.Component):
    library = "react-icons/im"
    tag = "ImFileMusic"


class ImFilePlay(rx.Component):
    library = "react-icons/im"
    tag = "ImFilePlay"


class ImFileVideo(rx.Component):
    library = "react-icons/im"
    tag = "ImFileVideo"


class ImFileZip(rx.Component):
    library = "react-icons/im"
    tag = "ImFileZip"


class ImCopy(rx.Component):
    library = "react-icons/im"
    tag = "ImCopy"


class ImPaste(rx.Component):
    library = "react-icons/im"
    tag = "ImPaste"


class ImStack(rx.Component):
    library = "react-icons/im"
    tag = "ImStack"


class ImFolder(rx.Component):
    library = "react-icons/im"
    tag = "ImFolder"


class ImFolderOpen(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderOpen"


class ImFolderPlus(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderPlus"


class ImFolderMinus(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderMinus"


class ImFolderDownload(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderDownload"


class ImFolderUpload(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderUpload"


class ImPriceTag(rx.Component):
    library = "react-icons/im"
    tag = "ImPriceTag"


class ImPriceTags(rx.Component):
    library = "react-icons/im"
    tag = "ImPriceTags"


class ImBarcode(rx.Component):
    library = "react-icons/im"
    tag = "ImBarcode"


class ImQrcode(rx.Component):
    library = "react-icons/im"
    tag = "ImQrcode"


class ImTicket(rx.Component):
    library = "react-icons/im"
    tag = "ImTicket"


class ImCart(rx.Component):
    library = "react-icons/im"
    tag = "ImCart"


class ImCoinDollar(rx.Component):
    library = "react-icons/im"
    tag = "ImCoinDollar"


class ImCoinEuro(rx.Component):
    library = "react-icons/im"
    tag = "ImCoinEuro"


class ImCoinPound(rx.Component):
    library = "react-icons/im"
    tag = "ImCoinPound"


class ImCoinYen(rx.Component):
    library = "react-icons/im"
    tag = "ImCoinYen"


class ImCreditCard(rx.Component):
    library = "react-icons/im"
    tag = "ImCreditCard"


class ImCalculator(rx.Component):
    library = "react-icons/im"
    tag = "ImCalculator"


class ImLifebuoy(rx.Component):
    library = "react-icons/im"
    tag = "ImLifebuoy"


class ImPhone(rx.Component):
    library = "react-icons/im"
    tag = "ImPhone"


class ImPhoneHangUp(rx.Component):
    library = "react-icons/im"
    tag = "ImPhoneHangUp"


class ImAddressBook(rx.Component):
    library = "react-icons/im"
    tag = "ImAddressBook"


class ImEnvelop(rx.Component):
    library = "react-icons/im"
    tag = "ImEnvelop"


class ImPushpin(rx.Component):
    library = "react-icons/im"
    tag = "ImPushpin"


class ImLocation(rx.Component):
    library = "react-icons/im"
    tag = "ImLocation"


class ImLocation2(rx.Component):
    library = "react-icons/im"
    tag = "ImLocation2"


class ImCompass(rx.Component):
    library = "react-icons/im"
    tag = "ImCompass"


class ImCompass2(rx.Component):
    library = "react-icons/im"
    tag = "ImCompass2"


class ImMap(rx.Component):
    library = "react-icons/im"
    tag = "ImMap"


class ImMap2(rx.Component):
    library = "react-icons/im"
    tag = "ImMap2"


class ImHistory(rx.Component):
    library = "react-icons/im"
    tag = "ImHistory"


class ImClock(rx.Component):
    library = "react-icons/im"
    tag = "ImClock"


class ImClock2(rx.Component):
    library = "react-icons/im"
    tag = "ImClock2"


class ImAlarm(rx.Component):
    library = "react-icons/im"
    tag = "ImAlarm"


class ImBell(rx.Component):
    library = "react-icons/im"
    tag = "ImBell"


class ImStopwatch(rx.Component):
    library = "react-icons/im"
    tag = "ImStopwatch"


class ImCalendar(rx.Component):
    library = "react-icons/im"
    tag = "ImCalendar"


class ImPrinter(rx.Component):
    library = "react-icons/im"
    tag = "ImPrinter"


class ImKeyboard(rx.Component):
    library = "react-icons/im"
    tag = "ImKeyboard"


class ImDisplay(rx.Component):
    library = "react-icons/im"
    tag = "ImDisplay"


class ImLaptop(rx.Component):
    library = "react-icons/im"
    tag = "ImLaptop"


class ImMobile(rx.Component):
    library = "react-icons/im"
    tag = "ImMobile"


class ImMobile2(rx.Component):
    library = "react-icons/im"
    tag = "ImMobile2"


class ImTablet(rx.Component):
    library = "react-icons/im"
    tag = "ImTablet"


class ImTv(rx.Component):
    library = "react-icons/im"
    tag = "ImTv"


class ImDrawer(rx.Component):
    library = "react-icons/im"
    tag = "ImDrawer"


class ImDrawer2(rx.Component):
    library = "react-icons/im"
    tag = "ImDrawer2"


class ImBoxAdd(rx.Component):
    library = "react-icons/im"
    tag = "ImBoxAdd"


class ImBoxRemove(rx.Component):
    library = "react-icons/im"
    tag = "ImBoxRemove"


class ImDownload(rx.Component):
    library = "react-icons/im"
    tag = "ImDownload"


class ImUpload(rx.Component):
    library = "react-icons/im"
    tag = "ImUpload"


class ImFloppyDisk(rx.Component):
    library = "react-icons/im"
    tag = "ImFloppyDisk"


class ImDrive(rx.Component):
    library = "react-icons/im"
    tag = "ImDrive"


class ImDatabase(rx.Component):
    library = "react-icons/im"
    tag = "ImDatabase"


class ImUndo(rx.Component):
    library = "react-icons/im"
    tag = "ImUndo"


class ImRedo(rx.Component):
    library = "react-icons/im"
    tag = "ImRedo"


class ImUndo2(rx.Component):
    library = "react-icons/im"
    tag = "ImUndo2"


class ImRedo2(rx.Component):
    library = "react-icons/im"
    tag = "ImRedo2"


class ImForward(rx.Component):
    library = "react-icons/im"
    tag = "ImForward"


class ImReply(rx.Component):
    library = "react-icons/im"
    tag = "ImReply"


class ImBubble(rx.Component):
    library = "react-icons/im"
    tag = "ImBubble"


class ImBubbles(rx.Component):
    library = "react-icons/im"
    tag = "ImBubbles"


class ImBubbles2(rx.Component):
    library = "react-icons/im"
    tag = "ImBubbles2"


class ImBubble2(rx.Component):
    library = "react-icons/im"
    tag = "ImBubble2"


class ImBubbles3(rx.Component):
    library = "react-icons/im"
    tag = "ImBubbles3"


class ImBubbles4(rx.Component):
    library = "react-icons/im"
    tag = "ImBubbles4"


class ImUser(rx.Component):
    library = "react-icons/im"
    tag = "ImUser"


class ImUsers(rx.Component):
    library = "react-icons/im"
    tag = "ImUsers"


class ImUserPlus(rx.Component):
    library = "react-icons/im"
    tag = "ImUserPlus"


class ImUserMinus(rx.Component):
    library = "react-icons/im"
    tag = "ImUserMinus"


class ImUserCheck(rx.Component):
    library = "react-icons/im"
    tag = "ImUserCheck"


class ImUserTie(rx.Component):
    library = "react-icons/im"
    tag = "ImUserTie"


class ImQuotesLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImQuotesLeft"


class ImQuotesRight(rx.Component):
    library = "react-icons/im"
    tag = "ImQuotesRight"


class ImHourGlass(rx.Component):
    library = "react-icons/im"
    tag = "ImHourGlass"


class ImSpinner(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner"


class ImSpinner2(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner2"


class ImSpinner3(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner3"


class ImSpinner4(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner4"


class ImSpinner5(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner5"


class ImSpinner6(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner6"


class ImSpinner7(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner7"


class ImSpinner8(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner8"


class ImSpinner9(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner9"


class ImSpinner10(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner10"


class ImSpinner11(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner11"


class ImBinoculars(rx.Component):
    library = "react-icons/im"
    tag = "ImBinoculars"


class ImSearch(rx.Component):
    library = "react-icons/im"
    tag = "ImSearch"


class ImZoomIn(rx.Component):
    library = "react-icons/im"
    tag = "ImZoomIn"


class ImZoomOut(rx.Component):
    library = "react-icons/im"
    tag = "ImZoomOut"


class ImEnlarge(rx.Component):
    library = "react-icons/im"
    tag = "ImEnlarge"


class ImShrink(rx.Component):
    library = "react-icons/im"
    tag = "ImShrink"


class ImEnlarge2(rx.Component):
    library = "react-icons/im"
    tag = "ImEnlarge2"


class ImShrink2(rx.Component):
    library = "react-icons/im"
    tag = "ImShrink2"


class ImKey(rx.Component):
    library = "react-icons/im"
    tag = "ImKey"


class ImKey2(rx.Component):
    library = "react-icons/im"
    tag = "ImKey2"


class ImLock(rx.Component):
    library = "react-icons/im"
    tag = "ImLock"


class ImUnlocked(rx.Component):
    library = "react-icons/im"
    tag = "ImUnlocked"


class ImWrench(rx.Component):
    library = "react-icons/im"
    tag = "ImWrench"


class ImEqualizer(rx.Component):
    library = "react-icons/im"
    tag = "ImEqualizer"


class ImEqualizer2(rx.Component):
    library = "react-icons/im"
    tag = "ImEqualizer2"


class ImCog(rx.Component):
    library = "react-icons/im"
    tag = "ImCog"


class ImCogs(rx.Component):
    library = "react-icons/im"
    tag = "ImCogs"


class ImHammer(rx.Component):
    library = "react-icons/im"
    tag = "ImHammer"


class ImMagicWand(rx.Component):
    library = "react-icons/im"
    tag = "ImMagicWand"


class ImAidKit(rx.Component):
    library = "react-icons/im"
    tag = "ImAidKit"


class ImBug(rx.Component):
    library = "react-icons/im"
    tag = "ImBug"


class ImPieChart(rx.Component):
    library = "react-icons/im"
    tag = "ImPieChart"


class ImStatsDots(rx.Component):
    library = "react-icons/im"
    tag = "ImStatsDots"


class ImStatsBars(rx.Component):
    library = "react-icons/im"
    tag = "ImStatsBars"


class ImStatsBars2(rx.Component):
    library = "react-icons/im"
    tag = "ImStatsBars2"


class ImTrophy(rx.Component):
    library = "react-icons/im"
    tag = "ImTrophy"


class ImGift(rx.Component):
    library = "react-icons/im"
    tag = "ImGift"


class ImGlass(rx.Component):
    library = "react-icons/im"
    tag = "ImGlass"


class ImGlass2(rx.Component):
    library = "react-icons/im"
    tag = "ImGlass2"


class ImMug(rx.Component):
    library = "react-icons/im"
    tag = "ImMug"


class ImSpoonKnife(rx.Component):
    library = "react-icons/im"
    tag = "ImSpoonKnife"


class ImLeaf(rx.Component):
    library = "react-icons/im"
    tag = "ImLeaf"


class ImRocket(rx.Component):
    library = "react-icons/im"
    tag = "ImRocket"


class ImMeter(rx.Component):
    library = "react-icons/im"
    tag = "ImMeter"


class ImMeter2(rx.Component):
    library = "react-icons/im"
    tag = "ImMeter2"


class ImHammer2(rx.Component):
    library = "react-icons/im"
    tag = "ImHammer2"


class ImFire(rx.Component):
    library = "react-icons/im"
    tag = "ImFire"


class ImLab(rx.Component):
    library = "react-icons/im"
    tag = "ImLab"


class ImMagnet(rx.Component):
    library = "react-icons/im"
    tag = "ImMagnet"


class ImBin(rx.Component):
    library = "react-icons/im"
    tag = "ImBin"


class ImBin2(rx.Component):
    library = "react-icons/im"
    tag = "ImBin2"


class ImBriefcase(rx.Component):
    library = "react-icons/im"
    tag = "ImBriefcase"


class ImAirplane(rx.Component):
    library = "react-icons/im"
    tag = "ImAirplane"


class ImTruck(rx.Component):
    library = "react-icons/im"
    tag = "ImTruck"


class ImRoad(rx.Component):
    library = "react-icons/im"
    tag = "ImRoad"


class ImAccessibility(rx.Component):
    library = "react-icons/im"
    tag = "ImAccessibility"


class ImTarget(rx.Component):
    library = "react-icons/im"
    tag = "ImTarget"


class ImShield(rx.Component):
    library = "react-icons/im"
    tag = "ImShield"


class ImPower(rx.Component):
    library = "react-icons/im"
    tag = "ImPower"


class ImSwitch(rx.Component):
    library = "react-icons/im"
    tag = "ImSwitch"


class ImPowerCord(rx.Component):
    library = "react-icons/im"
    tag = "ImPowerCord"


class ImClipboard(rx.Component):
    library = "react-icons/im"
    tag = "ImClipboard"


class ImListNumbered(rx.Component):
    library = "react-icons/im"
    tag = "ImListNumbered"


class ImList(rx.Component):
    library = "react-icons/im"
    tag = "ImList"


class ImList2(rx.Component):
    library = "react-icons/im"
    tag = "ImList2"


class ImTree(rx.Component):
    library = "react-icons/im"
    tag = "ImTree"


class ImMenu(rx.Component):
    library = "react-icons/im"
    tag = "ImMenu"


class ImMenu2(rx.Component):
    library = "react-icons/im"
    tag = "ImMenu2"


class ImMenu3(rx.Component):
    library = "react-icons/im"
    tag = "ImMenu3"


class ImMenu4(rx.Component):
    library = "react-icons/im"
    tag = "ImMenu4"


class ImCloud(rx.Component):
    library = "react-icons/im"
    tag = "ImCloud"


class ImCloudDownload(rx.Component):
    library = "react-icons/im"
    tag = "ImCloudDownload"


class ImCloudUpload(rx.Component):
    library = "react-icons/im"
    tag = "ImCloudUpload"


class ImCloudCheck(rx.Component):
    library = "react-icons/im"
    tag = "ImCloudCheck"


class ImDownload2(rx.Component):
    library = "react-icons/im"
    tag = "ImDownload2"


class ImUpload2(rx.Component):
    library = "react-icons/im"
    tag = "ImUpload2"


class ImDownload3(rx.Component):
    library = "react-icons/im"
    tag = "ImDownload3"


class ImUpload3(rx.Component):
    library = "react-icons/im"
    tag = "ImUpload3"


class ImSphere(rx.Component):
    library = "react-icons/im"
    tag = "ImSphere"


class ImEarth(rx.Component):
    library = "react-icons/im"
    tag = "ImEarth"


class ImLink(rx.Component):
    library = "react-icons/im"
    tag = "ImLink"


class ImFlag(rx.Component):
    library = "react-icons/im"
    tag = "ImFlag"


class ImAttachment(rx.Component):
    library = "react-icons/im"
    tag = "ImAttachment"


class ImEye(rx.Component):
    library = "react-icons/im"
    tag = "ImEye"


class ImEyePlus(rx.Component):
    library = "react-icons/im"
    tag = "ImEyePlus"


class ImEyeMinus(rx.Component):
    library = "react-icons/im"
    tag = "ImEyeMinus"


class ImEyeBlocked(rx.Component):
    library = "react-icons/im"
    tag = "ImEyeBlocked"


class ImBookmark(rx.Component):
    library = "react-icons/im"
    tag = "ImBookmark"


class ImBookmarks(rx.Component):
    library = "react-icons/im"
    tag = "ImBookmarks"


class ImSun(rx.Component):
    library = "react-icons/im"
    tag = "ImSun"


class ImContrast(rx.Component):
    library = "react-icons/im"
    tag = "ImContrast"


class ImBrightnessContrast(rx.Component):
    library = "react-icons/im"
    tag = "ImBrightnessContrast"


class ImStarEmpty(rx.Component):
    library = "react-icons/im"
    tag = "ImStarEmpty"


class ImStarHalf(rx.Component):
    library = "react-icons/im"
    tag = "ImStarHalf"


class ImStarFull(rx.Component):
    library = "react-icons/im"
    tag = "ImStarFull"


class ImHeart(rx.Component):
    library = "react-icons/im"
    tag = "ImHeart"


class ImHeartBroken(rx.Component):
    library = "react-icons/im"
    tag = "ImHeartBroken"


class ImMan(rx.Component):
    library = "react-icons/im"
    tag = "ImMan"


class ImWoman(rx.Component):
    library = "react-icons/im"
    tag = "ImWoman"


class ImManWoman(rx.Component):
    library = "react-icons/im"
    tag = "ImManWoman"


class ImHappy(rx.Component):
    library = "react-icons/im"
    tag = "ImHappy"


class ImHappy2(rx.Component):
    library = "react-icons/im"
    tag = "ImHappy2"


class ImSmile(rx.Component):
    library = "react-icons/im"
    tag = "ImSmile"


class ImSmile2(rx.Component):
    library = "react-icons/im"
    tag = "ImSmile2"


class ImTongue(rx.Component):
    library = "react-icons/im"
    tag = "ImTongue"


class ImTongue2(rx.Component):
    library = "react-icons/im"
    tag = "ImTongue2"


class ImSad(rx.Component):
    library = "react-icons/im"
    tag = "ImSad"


class ImSad2(rx.Component):
    library = "react-icons/im"
    tag = "ImSad2"


class ImWink(rx.Component):
    library = "react-icons/im"
    tag = "ImWink"


class ImWink2(rx.Component):
    library = "react-icons/im"
    tag = "ImWink2"


class ImGrin(rx.Component):
    library = "react-icons/im"
    tag = "ImGrin"


class ImGrin2(rx.Component):
    library = "react-icons/im"
    tag = "ImGrin2"


class ImCool(rx.Component):
    library = "react-icons/im"
    tag = "ImCool"


class ImCool2(rx.Component):
    library = "react-icons/im"
    tag = "ImCool2"


class ImAngry(rx.Component):
    library = "react-icons/im"
    tag = "ImAngry"


class ImAngry2(rx.Component):
    library = "react-icons/im"
    tag = "ImAngry2"


class ImEvil(rx.Component):
    library = "react-icons/im"
    tag = "ImEvil"


class ImEvil2(rx.Component):
    library = "react-icons/im"
    tag = "ImEvil2"


class ImShocked(rx.Component):
    library = "react-icons/im"
    tag = "ImShocked"


class ImShocked2(rx.Component):
    library = "react-icons/im"
    tag = "ImShocked2"


class ImBaffled(rx.Component):
    library = "react-icons/im"
    tag = "ImBaffled"


class ImBaffled2(rx.Component):
    library = "react-icons/im"
    tag = "ImBaffled2"


class ImConfused(rx.Component):
    library = "react-icons/im"
    tag = "ImConfused"


class ImConfused2(rx.Component):
    library = "react-icons/im"
    tag = "ImConfused2"


class ImNeutral(rx.Component):
    library = "react-icons/im"
    tag = "ImNeutral"


class ImNeutral2(rx.Component):
    library = "react-icons/im"
    tag = "ImNeutral2"


class ImHipster(rx.Component):
    library = "react-icons/im"
    tag = "ImHipster"


class ImHipster2(rx.Component):
    library = "react-icons/im"
    tag = "ImHipster2"


class ImWondering(rx.Component):
    library = "react-icons/im"
    tag = "ImWondering"


class ImWondering2(rx.Component):
    library = "react-icons/im"
    tag = "ImWondering2"


class ImSleepy(rx.Component):
    library = "react-icons/im"
    tag = "ImSleepy"


class ImSleepy2(rx.Component):
    library = "react-icons/im"
    tag = "ImSleepy2"


class ImFrustrated(rx.Component):
    library = "react-icons/im"
    tag = "ImFrustrated"


class ImFrustrated2(rx.Component):
    library = "react-icons/im"
    tag = "ImFrustrated2"


class ImCrying(rx.Component):
    library = "react-icons/im"
    tag = "ImCrying"


class ImCrying2(rx.Component):
    library = "react-icons/im"
    tag = "ImCrying2"


class ImPointUp(rx.Component):
    library = "react-icons/im"
    tag = "ImPointUp"


class ImPointRight(rx.Component):
    library = "react-icons/im"
    tag = "ImPointRight"


class ImPointDown(rx.Component):
    library = "react-icons/im"
    tag = "ImPointDown"


class ImPointLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImPointLeft"


class ImWarning(rx.Component):
    library = "react-icons/im"
    tag = "ImWarning"


class ImNotification(rx.Component):
    library = "react-icons/im"
    tag = "ImNotification"


class ImQuestion(rx.Component):
    library = "react-icons/im"
    tag = "ImQuestion"


class ImPlus(rx.Component):
    library = "react-icons/im"
    tag = "ImPlus"


class ImMinus(rx.Component):
    library = "react-icons/im"
    tag = "ImMinus"


class ImInfo(rx.Component):
    library = "react-icons/im"
    tag = "ImInfo"


class ImCancelCircle(rx.Component):
    library = "react-icons/im"
    tag = "ImCancelCircle"


class ImBlocked(rx.Component):
    library = "react-icons/im"
    tag = "ImBlocked"


class ImCross(rx.Component):
    library = "react-icons/im"
    tag = "ImCross"


class ImCheckmark(rx.Component):
    library = "react-icons/im"
    tag = "ImCheckmark"


class ImCheckmark2(rx.Component):
    library = "react-icons/im"
    tag = "ImCheckmark2"


class ImSpellCheck(rx.Component):
    library = "react-icons/im"
    tag = "ImSpellCheck"


class ImEnter(rx.Component):
    library = "react-icons/im"
    tag = "ImEnter"


class ImExit(rx.Component):
    library = "react-icons/im"
    tag = "ImExit"


class ImPlay2(rx.Component):
    library = "react-icons/im"
    tag = "ImPlay2"


class ImPause(rx.Component):
    library = "react-icons/im"
    tag = "ImPause"


class ImStop(rx.Component):
    library = "react-icons/im"
    tag = "ImStop"


class ImPrevious(rx.Component):
    library = "react-icons/im"
    tag = "ImPrevious"


class ImNext(rx.Component):
    library = "react-icons/im"
    tag = "ImNext"


class ImBackward(rx.Component):
    library = "react-icons/im"
    tag = "ImBackward"


class ImForward2(rx.Component):
    library = "react-icons/im"
    tag = "ImForward2"


class ImPlay3(rx.Component):
    library = "react-icons/im"
    tag = "ImPlay3"


class ImPause2(rx.Component):
    library = "react-icons/im"
    tag = "ImPause2"


class ImStop2(rx.Component):
    library = "react-icons/im"
    tag = "ImStop2"


class ImBackward2(rx.Component):
    library = "react-icons/im"
    tag = "ImBackward2"


class ImForward3(rx.Component):
    library = "react-icons/im"
    tag = "ImForward3"


class ImFirst(rx.Component):
    library = "react-icons/im"
    tag = "ImFirst"


class ImLast(rx.Component):
    library = "react-icons/im"
    tag = "ImLast"


class ImPrevious2(rx.Component):
    library = "react-icons/im"
    tag = "ImPrevious2"


class ImNext2(rx.Component):
    library = "react-icons/im"
    tag = "ImNext2"


class ImEject(rx.Component):
    library = "react-icons/im"
    tag = "ImEject"


class ImVolumeHigh(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeHigh"


class ImVolumeMedium(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeMedium"


class ImVolumeLow(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeLow"


class ImVolumeMute(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeMute"


class ImVolumeMute2(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeMute2"


class ImVolumeIncrease(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeIncrease"


class ImVolumeDecrease(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeDecrease"


class ImLoop(rx.Component):
    library = "react-icons/im"
    tag = "ImLoop"


class ImLoop2(rx.Component):
    library = "react-icons/im"
    tag = "ImLoop2"


class ImInfinite(rx.Component):
    library = "react-icons/im"
    tag = "ImInfinite"


class ImShuffle(rx.Component):
    library = "react-icons/im"
    tag = "ImShuffle"


class ImArrowUpLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUpLeft"


class ImArrowUp(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUp"


class ImArrowUpRight(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUpRight"


class ImArrowRight(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowRight"


class ImArrowDownRight(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDownRight"


class ImArrowDown(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDown"


class ImArrowDownLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDownLeft"


class ImArrowLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowLeft"


class ImArrowUpLeft2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUpLeft2"


class ImArrowUp2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUp2"


class ImArrowUpRight2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUpRight2"


class ImArrowRight2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowRight2"


class ImArrowDownRight2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDownRight2"


class ImArrowDown2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDown2"


class ImArrowDownLeft2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDownLeft2"


class ImArrowLeft2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowLeft2"


class ImCircleUp(rx.Component):
    library = "react-icons/im"
    tag = "ImCircleUp"


class ImCircleRight(rx.Component):
    library = "react-icons/im"
    tag = "ImCircleRight"


class ImCircleDown(rx.Component):
    library = "react-icons/im"
    tag = "ImCircleDown"


class ImCircleLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImCircleLeft"


class ImTab(rx.Component):
    library = "react-icons/im"
    tag = "ImTab"


class ImMoveUp(rx.Component):
    library = "react-icons/im"
    tag = "ImMoveUp"


class ImMoveDown(rx.Component):
    library = "react-icons/im"
    tag = "ImMoveDown"


class ImSortAlphaAsc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortAlphaAsc"


class ImSortAlphaDesc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortAlphaDesc"


class ImSortNumericAsc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortNumericAsc"


class ImSortNumbericDesc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortNumbericDesc"


class ImSortAmountAsc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortAmountAsc"


class ImSortAmountDesc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortAmountDesc"


class ImCommand(rx.Component):
    library = "react-icons/im"
    tag = "ImCommand"


class ImShift(rx.Component):
    library = "react-icons/im"
    tag = "ImShift"


class ImCtrl(rx.Component):
    library = "react-icons/im"
    tag = "ImCtrl"


class ImOpt(rx.Component):
    library = "react-icons/im"
    tag = "ImOpt"


class ImCheckboxChecked(rx.Component):
    library = "react-icons/im"
    tag = "ImCheckboxChecked"


class ImCheckboxUnchecked(rx.Component):
    library = "react-icons/im"
    tag = "ImCheckboxUnchecked"


class ImRadioChecked(rx.Component):
    library = "react-icons/im"
    tag = "ImRadioChecked"


class ImRadioChecked2(rx.Component):
    library = "react-icons/im"
    tag = "ImRadioChecked2"


class ImRadioUnchecked(rx.Component):
    library = "react-icons/im"
    tag = "ImRadioUnchecked"


class ImCrop(rx.Component):
    library = "react-icons/im"
    tag = "ImCrop"


class ImMakeGroup(rx.Component):
    library = "react-icons/im"
    tag = "ImMakeGroup"


class ImUngroup(rx.Component):
    library = "react-icons/im"
    tag = "ImUngroup"


class ImScissors(rx.Component):
    library = "react-icons/im"
    tag = "ImScissors"


class ImFilter(rx.Component):
    library = "react-icons/im"
    tag = "ImFilter"


class ImFont(rx.Component):
    library = "react-icons/im"
    tag = "ImFont"


class ImLigature(rx.Component):
    library = "react-icons/im"
    tag = "ImLigature"


class ImLigature2(rx.Component):
    library = "react-icons/im"
    tag = "ImLigature2"


class ImTextHeight(rx.Component):
    library = "react-icons/im"
    tag = "ImTextHeight"


class ImTextWidth(rx.Component):
    library = "react-icons/im"
    tag = "ImTextWidth"


class ImFontSize(rx.Component):
    library = "react-icons/im"
    tag = "ImFontSize"


class ImBold(rx.Component):
    library = "react-icons/im"
    tag = "ImBold"


class ImUnderline(rx.Component):
    library = "react-icons/im"
    tag = "ImUnderline"


class ImItalic(rx.Component):
    library = "react-icons/im"
    tag = "ImItalic"


class ImStrikethrough(rx.Component):
    library = "react-icons/im"
    tag = "ImStrikethrough"


class ImOmega(rx.Component):
    library = "react-icons/im"
    tag = "ImOmega"


class ImSigma(rx.Component):
    library = "react-icons/im"
    tag = "ImSigma"


class ImPageBreak(rx.Component):
    library = "react-icons/im"
    tag = "ImPageBreak"


class ImSuperscript(rx.Component):
    library = "react-icons/im"
    tag = "ImSuperscript"


class ImSubscript(rx.Component):
    library = "react-icons/im"
    tag = "ImSubscript"


class ImSuperscript2(rx.Component):
    library = "react-icons/im"
    tag = "ImSuperscript2"


class ImSubscript2(rx.Component):
    library = "react-icons/im"
    tag = "ImSubscript2"


class ImTextColor(rx.Component):
    library = "react-icons/im"
    tag = "ImTextColor"


class ImPagebreak(rx.Component):
    library = "react-icons/im"
    tag = "ImPagebreak"


class ImClearFormatting(rx.Component):
    library = "react-icons/im"
    tag = "ImClearFormatting"


class ImTable(rx.Component):
    library = "react-icons/im"
    tag = "ImTable"


class ImTable2(rx.Component):
    library = "react-icons/im"
    tag = "ImTable2"


class ImInsertTemplate(rx.Component):
    library = "react-icons/im"
    tag = "ImInsertTemplate"


class ImPilcrow(rx.Component):
    library = "react-icons/im"
    tag = "ImPilcrow"


class ImLtr(rx.Component):
    library = "react-icons/im"
    tag = "ImLtr"


class ImRtl(rx.Component):
    library = "react-icons/im"
    tag = "ImRtl"


class ImSection(rx.Component):
    library = "react-icons/im"
    tag = "ImSection"


class ImParagraphLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImParagraphLeft"


class ImParagraphCenter(rx.Component):
    library = "react-icons/im"
    tag = "ImParagraphCenter"


class ImParagraphRight(rx.Component):
    library = "react-icons/im"
    tag = "ImParagraphRight"


class ImParagraphJustify(rx.Component):
    library = "react-icons/im"
    tag = "ImParagraphJustify"


class ImIndentIncrease(rx.Component):
    library = "react-icons/im"
    tag = "ImIndentIncrease"


class ImIndentDecrease(rx.Component):
    library = "react-icons/im"
    tag = "ImIndentDecrease"


class ImShare(rx.Component):
    library = "react-icons/im"
    tag = "ImShare"


class ImNewTab(rx.Component):
    library = "react-icons/im"
    tag = "ImNewTab"


class ImEmbed(rx.Component):
    library = "react-icons/im"
    tag = "ImEmbed"


class ImEmbed2(rx.Component):
    library = "react-icons/im"
    tag = "ImEmbed2"


class ImTerminal(rx.Component):
    library = "react-icons/im"
    tag = "ImTerminal"


class ImShare2(rx.Component):
    library = "react-icons/im"
    tag = "ImShare2"


class ImMail(rx.Component):
    library = "react-icons/im"
    tag = "ImMail"


class ImMail2(rx.Component):
    library = "react-icons/im"
    tag = "ImMail2"


class ImMail3(rx.Component):
    library = "react-icons/im"
    tag = "ImMail3"


class ImMail4(rx.Component):
    library = "react-icons/im"
    tag = "ImMail4"


class ImAmazon(rx.Component):
    library = "react-icons/im"
    tag = "ImAmazon"


class ImGoogle(rx.Component):
    library = "react-icons/im"
    tag = "ImGoogle"


class ImGoogle2(rx.Component):
    library = "react-icons/im"
    tag = "ImGoogle2"


class ImGoogle3(rx.Component):
    library = "react-icons/im"
    tag = "ImGoogle3"


class ImGooglePlus(rx.Component):
    library = "react-icons/im"
    tag = "ImGooglePlus"


class ImGooglePlus2(rx.Component):
    library = "react-icons/im"
    tag = "ImGooglePlus2"


class ImGooglePlus3(rx.Component):
    library = "react-icons/im"
    tag = "ImGooglePlus3"


class ImHangouts(rx.Component):
    library = "react-icons/im"
    tag = "ImHangouts"


class ImGoogleDrive(rx.Component):
    library = "react-icons/im"
    tag = "ImGoogleDrive"


class ImFacebook(rx.Component):
    library = "react-icons/im"
    tag = "ImFacebook"


class ImFacebook2(rx.Component):
    library = "react-icons/im"
    tag = "ImFacebook2"


class ImInstagram(rx.Component):
    library = "react-icons/im"
    tag = "ImInstagram"


class ImWhatsapp(rx.Component):
    library = "react-icons/im"
    tag = "ImWhatsapp"


class ImSpotify(rx.Component):
    library = "react-icons/im"
    tag = "ImSpotify"


class ImTelegram(rx.Component):
    library = "react-icons/im"
    tag = "ImTelegram"


class ImTwitter(rx.Component):
    library = "react-icons/im"
    tag = "ImTwitter"


class ImVine(rx.Component):
    library = "react-icons/im"
    tag = "ImVine"


class ImVk(rx.Component):
    library = "react-icons/im"
    tag = "ImVk"


class ImRenren(rx.Component):
    library = "react-icons/im"
    tag = "ImRenren"


class ImSinaWeibo(rx.Component):
    library = "react-icons/im"
    tag = "ImSinaWeibo"


class ImRss(rx.Component):
    library = "react-icons/im"
    tag = "ImRss"


class ImRss2(rx.Component):
    library = "react-icons/im"
    tag = "ImRss2"


class ImYoutube(rx.Component):
    library = "react-icons/im"
    tag = "ImYoutube"


class ImYoutube2(rx.Component):
    library = "react-icons/im"
    tag = "ImYoutube2"


class ImTwitch(rx.Component):
    library = "react-icons/im"
    tag = "ImTwitch"


class ImVimeo(rx.Component):
    library = "react-icons/im"
    tag = "ImVimeo"


class ImVimeo2(rx.Component):
    library = "react-icons/im"
    tag = "ImVimeo2"


class ImLanyrd(rx.Component):
    library = "react-icons/im"
    tag = "ImLanyrd"


class ImFlickr(rx.Component):
    library = "react-icons/im"
    tag = "ImFlickr"


class ImFlickr2(rx.Component):
    library = "react-icons/im"
    tag = "ImFlickr2"


class ImFlickr3(rx.Component):
    library = "react-icons/im"
    tag = "ImFlickr3"


class ImFlickr4(rx.Component):
    library = "react-icons/im"
    tag = "ImFlickr4"


class ImDribbble(rx.Component):
    library = "react-icons/im"
    tag = "ImDribbble"


class ImBehance(rx.Component):
    library = "react-icons/im"
    tag = "ImBehance"


class ImBehance2(rx.Component):
    library = "react-icons/im"
    tag = "ImBehance2"


class ImDeviantart(rx.Component):
    library = "react-icons/im"
    tag = "ImDeviantart"


class Im500Px(rx.Component):
    library = "react-icons/im"
    tag = "Im500Px"


class ImSteam(rx.Component):
    library = "react-icons/im"
    tag = "ImSteam"


class ImSteam2(rx.Component):
    library = "react-icons/im"
    tag = "ImSteam2"


class ImDropbox(rx.Component):
    library = "react-icons/im"
    tag = "ImDropbox"


class ImOnedrive(rx.Component):
    library = "react-icons/im"
    tag = "ImOnedrive"


class ImGithub(rx.Component):
    library = "react-icons/im"
    tag = "ImGithub"


class ImNpm(rx.Component):
    library = "react-icons/im"
    tag = "ImNpm"


class ImBasecamp(rx.Component):
    library = "react-icons/im"
    tag = "ImBasecamp"


class ImTrello(rx.Component):
    library = "react-icons/im"
    tag = "ImTrello"


class ImWordpress(rx.Component):
    library = "react-icons/im"
    tag = "ImWordpress"


class ImJoomla(rx.Component):
    library = "react-icons/im"
    tag = "ImJoomla"


class ImEllo(rx.Component):
    library = "react-icons/im"
    tag = "ImEllo"


class ImBlogger(rx.Component):
    library = "react-icons/im"
    tag = "ImBlogger"


class ImBlogger2(rx.Component):
    library = "react-icons/im"
    tag = "ImBlogger2"


class ImTumblr(rx.Component):
    library = "react-icons/im"
    tag = "ImTumblr"


class ImTumblr2(rx.Component):
    library = "react-icons/im"
    tag = "ImTumblr2"


class ImYahoo(rx.Component):
    library = "react-icons/im"
    tag = "ImYahoo"


class ImYahoo2(rx.Component):
    library = "react-icons/im"
    tag = "ImYahoo2"


class ImTux(rx.Component):
    library = "react-icons/im"
    tag = "ImTux"


class ImAppleinc(rx.Component):
    library = "react-icons/im"
    tag = "ImAppleinc"


class ImFinder(rx.Component):
    library = "react-icons/im"
    tag = "ImFinder"


class ImAndroid(rx.Component):
    library = "react-icons/im"
    tag = "ImAndroid"


class ImWindows(rx.Component):
    library = "react-icons/im"
    tag = "ImWindows"


class ImWindows8(rx.Component):
    library = "react-icons/im"
    tag = "ImWindows8"


class ImSoundcloud(rx.Component):
    library = "react-icons/im"
    tag = "ImSoundcloud"


class ImSoundcloud2(rx.Component):
    library = "react-icons/im"
    tag = "ImSoundcloud2"


class ImSkype(rx.Component):
    library = "react-icons/im"
    tag = "ImSkype"


class ImReddit(rx.Component):
    library = "react-icons/im"
    tag = "ImReddit"


class ImHackernews(rx.Component):
    library = "react-icons/im"
    tag = "ImHackernews"


class ImWikipedia(rx.Component):
    library = "react-icons/im"
    tag = "ImWikipedia"


class ImLinkedin(rx.Component):
    library = "react-icons/im"
    tag = "ImLinkedin"


class ImLinkedin2(rx.Component):
    library = "react-icons/im"
    tag = "ImLinkedin2"


class ImLastfm(rx.Component):
    library = "react-icons/im"
    tag = "ImLastfm"


class ImLastfm2(rx.Component):
    library = "react-icons/im"
    tag = "ImLastfm2"


class ImDelicious(rx.Component):
    library = "react-icons/im"
    tag = "ImDelicious"


class ImStumbleupon(rx.Component):
    library = "react-icons/im"
    tag = "ImStumbleupon"


class ImStumbleupon2(rx.Component):
    library = "react-icons/im"
    tag = "ImStumbleupon2"


class ImStackoverflow(rx.Component):
    library = "react-icons/im"
    tag = "ImStackoverflow"


class ImPinterest(rx.Component):
    library = "react-icons/im"
    tag = "ImPinterest"


class ImPinterest2(rx.Component):
    library = "react-icons/im"
    tag = "ImPinterest2"


class ImXing(rx.Component):
    library = "react-icons/im"
    tag = "ImXing"


class ImXing2(rx.Component):
    library = "react-icons/im"
    tag = "ImXing2"


class ImFlattr(rx.Component):
    library = "react-icons/im"
    tag = "ImFlattr"


class ImFoursquare(rx.Component):
    library = "react-icons/im"
    tag = "ImFoursquare"


class ImYelp(rx.Component):
    library = "react-icons/im"
    tag = "ImYelp"


class ImPaypal(rx.Component):
    library = "react-icons/im"
    tag = "ImPaypal"


class ImChrome(rx.Component):
    library = "react-icons/im"
    tag = "ImChrome"


class ImFirefox(rx.Component):
    library = "react-icons/im"
    tag = "ImFirefox"


class ImIe(rx.Component):
    library = "react-icons/im"
    tag = "ImIe"


class ImEdge(rx.Component):
    library = "react-icons/im"
    tag = "ImEdge"


class ImSafari(rx.Component):
    library = "react-icons/im"
    tag = "ImSafari"


class ImOpera(rx.Component):
    library = "react-icons/im"
    tag = "ImOpera"


class ImFilePdf(rx.Component):
    library = "react-icons/im"
    tag = "ImFilePdf"


class ImFileOpenoffice(rx.Component):
    library = "react-icons/im"
    tag = "ImFileOpenoffice"


class ImFileWord(rx.Component):
    library = "react-icons/im"
    tag = "ImFileWord"


class ImFileExcel(rx.Component):
    library = "react-icons/im"
    tag = "ImFileExcel"


class ImLibreoffice(rx.Component):
    library = "react-icons/im"
    tag = "ImLibreoffice"


class ImHtmlFive(rx.Component):
    library = "react-icons/im"
    tag = "ImHtmlFive"


class ImHtmlFive2(rx.Component):
    library = "react-icons/im"
    tag = "ImHtmlFive2"


class ImCss3(rx.Component):
    library = "react-icons/im"
    tag = "ImCss3"


class ImGit(rx.Component):
    library = "react-icons/im"
    tag = "ImGit"


class ImCodepen(rx.Component):
    library = "react-icons/im"
    tag = "ImCodepen"


class ImSvg(rx.Component):
    library = "react-icons/im"
    tag = "ImSvg"


class ImIcoMoon(rx.Component):
    library = "react-icons/im"
    tag = "ImIcoMoon"


